@@ -1,5 +1,5 @@
 #
-# $Date: 2005/03/15 21:15:49 $
+# $Date: 2005/04/08 19:54:05 $
 #
 # File name layer functions
 #
@@ -52,6 +52,7 @@ $File::CONT_MENU      = 9;
 $File::REPORT         = 10;
 $File::EXPORT         = 11;
 $File::MD5LIST        = 12;
+$File::CONT_IMG       = 13;
 
 $File::REC_NO  = 0;
 $File::REC_YES = 1;
@@ -123,6 +124,9 @@ sub main {
         elsif ($view == $File::MD5LIST) {
             return md5list();
         }
+        elsif ($view == $File::CONT_IMG) {
+            return content_img();
+        }
     }
 
     Print::print_check_err("Invalid File View");
@@ -1742,6 +1746,13 @@ sub file_list_del {
 sub content_fr {
     Print::print_html_header_frameset("");
 
+    my $meta    = Args::get_meta('meta');
+    my $vol     = Args::get_vol('vol');
+    my $ftype   = $Caseman::vol2ftype{$vol};
+    my $img     = $Caseman::vol2path{$vol};
+    my $offset  = $Caseman::vol2start{$vol};
+    my $imgtype = $Caseman::vol2itype{$vol};
+
     print "<frameset rows=\"65,*\">\n";
 
     my $recmode = $File::REC_NO;
@@ -1750,12 +1761,6 @@ sub content_fr {
         $recmode = $Args::enc_args{'recmode'};
     }
     else {
-        my $meta    = Args::get_meta('meta');
-        my $vol     = Args::get_vol('vol');
-        my $ftype   = $Caseman::vol2ftype{$vol};
-        my $img     = $Caseman::vol2path{$vol};
-        my $offset  = $Caseman::vol2start{$vol};
-        my $imgtype = $Caseman::vol2itype{$vol};
 
         # We need to get the allocation status of this structure
         my $meta_int = $meta;
@@ -1781,16 +1786,44 @@ sub content_fr {
     }
     close(OUT);
 
+    # Get the file type so we can show the thumb nails automatically
+    if ($recmode == $File::REC_YES) {
+        Exec::exec_pipe(*OUT,
+"'$::TSKDIR/icat' -f $ftype -r  -o $offset -i $imgtype $img $meta | '$::FILE_EXE' -z -b -"
+        );
+    }
+    else {
+        Exec::exec_pipe(*OUT,
+"'$::TSKDIR/icat' -f $ftype  -o $offset -i $imgtype $img $meta | '$::FILE_EXE' -z -b -"
+        );
+    }
+
+    my $apptype = Exec::read_pipe_line(*OUT);
+    close(OUT);
+
+    $apptype = "Error getting file type"
+      if ((!defined $apptype) || ($apptype eq ""));
+
     # The menu for the different viewing options
     print "<frame src=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::CONT_MENU&"
       . "$Args::baseargs&dir=$Args::enc_args{'dir'}"
       . "&meta=$Args::enc_args{'meta'}&sort=$FIL_SORT_ASC&recmode=$recmode\">\n";
 
-    # Where the actual content will be displayed
-    print "<frame src=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::CONT"
-      . "&$Args::baseargs&dir=$Args::enc_args{'dir'}"
-      . "&meta=$Args::enc_args{'meta'}"
-      . "&sort=$FIL_SORT_ASC&recmode=$recmode\" name=\"cont2\">\n</frameset>";
+    # Print the image thumbnail
+    if (($apptype =~ /image data/) || ($apptype =~ /PC bitmap data/)) {
+        print "<frame src=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::CONT_IMG"
+          . "&$Args::baseargs&dir=$Args::enc_args{'dir'}"
+          . "&meta=$Args::enc_args{'meta'}"
+          . "&sort=$FIL_SORT_ASC&recmode=$recmode\" name=\"cont2\">\n</frameset>";
+    }
+    else {
+
+        # Where the actual content will be displayed
+        print "<frame src=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::CONT"
+          . "&$Args::baseargs&dir=$Args::enc_args{'dir'}"
+          . "&meta=$Args::enc_args{'meta'}"
+          . "&sort=$FIL_SORT_ASC&recmode=$recmode\" name=\"cont2\">\n</frameset>";
+    }
 
     Print::print_html_footer_frameset();
     return 0;
@@ -1812,9 +1845,7 @@ sub content_menu {
     my $imgtype = $Caseman::vol2itype{$vol};
     my $recmode = Args::get_recmode();
 
-    # get the type of contents
-    local *OUT;
-
+    # Get the file type
     if ($recmode == $File::REC_YES) {
         Exec::exec_pipe(*OUT,
 "'$::TSKDIR/icat' -f $ftype -r  -o $offset -i $imgtype $img $meta | '$::FILE_EXE' -z -b -"
@@ -1826,11 +1857,11 @@ sub content_menu {
         );
     }
 
-    $file_type = Exec::read_pipe_line(*OUT);
+    my $apptype = Exec::read_pipe_line(*OUT);
     close(OUT);
 
-    $file_type = "Error getting file type"
-      if ((!defined $file_type) || ($file_type eq ""));
+    $apptype = "Error getting file type"
+      if ((!defined $apptype) || ($apptype eq ""));
 
     # We already have the path in the content window below, so save space
     # print "<center><tt>$mnt$Args::args{'dir'}</tt>\n";
@@ -1857,10 +1888,14 @@ sub content_menu {
       . "Export</a></td>\n";
 
     # if the file is either image or HTML, then let them view it
-    if (   ($file_type =~ /image data/)
-        || ($file_type =~ /HTML document text/)
-        || ($file_type =~ /PC bitmap data/))
+    if (   ($apptype =~ /image data/)
+        || ($apptype =~ /PC bitmap data/))
     {
+        print "<td>*</td>\n<td><a href=\"$::PROGNAME?"
+          . "mod=$::MOD_FILE&view=$File::CONT_IMG$url\""
+          . "target=\"cont2\">View</a></td>\n";
+    }
+    elsif ($apptype =~ /HTML document text/) {
         print "<td>*</td>\n<td><a href=\"$::PROGNAME?"
           . "mod=$::MOD_APPVIEW&view=$Appview::CELL_FRAME$url\""
           . "target=\"_blank\">View</a></td>\n";
@@ -1873,7 +1908,7 @@ sub content_menu {
 
     print "</tr></table>\n";
 
-    print "File Type: $file_type\n";
+    print "File Type: $apptype\n";
     print
       "<br><font color=\"$::DEL_COLOR[0]\">Deleted File Recovery Mode</font>\n"
       if ($recmode == $File::REC_YES);
@@ -1941,6 +1976,34 @@ sub content {
     return 0;
 }
 
+sub content_img {
+
+    Print::print_html_header("image content");
+
+    my $vol   = Args::get_vol('vol');
+    my $mnt   = $Caseman::vol2mnt{$vol};
+    my $fname = "$mnt$Args::args{'dir'}";
+    $fname =~ s/\/\//\//g;
+
+    my $url =
+        "&$Args::baseargs&meta=$Args::enc_args{'meta'}"
+      . "&dir=$Args::enc_args{'dir'}&"
+      . "cell_mode=2&recmode=$Args::enc_args{'recmode'}";
+
+    print "<tt>$fname</tt><br>\n"
+      . "<table><tr>\n"
+      . "<td width=200>"
+      . "<img src=\"$::PROGNAME?mod=$::MOD_APPVIEW&view=$Appview::CELL_CONT${url}\" width=\"200\"></td>\n"
+      . "<td valign=top>"
+      . "<a href=\"$::PROGNAME?mod=$::MOD_APPVIEW&view=$Appview::CELL_CONT${url}\" "
+      . "target=_blank>View Full Size Image</a><br>\n</td>\n"
+      . "</tr></table>\n";
+
+    Print::print_html_footer();
+
+    return 0;
+}
+
 # Export the contents of a file
 sub export {
 
@@ -2138,13 +2201,13 @@ sub report {
     Exec::exec_pipe(*OUT,
 "'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::FILE_EXE' -z -b -"
     );
-    my $file_type = Exec::read_pipe_line(*OUT);
+    my $apptype = Exec::read_pipe_line(*OUT);
     close(OUT);
 
-    $file_type = "Error getting file type"
-      if ((!defined $file_type) || ($file_type eq ""));
+    $apptype = "Error getting file type"
+      if ((!defined $apptype) || ($apptype eq ""));
 
-    print "\nFile Type: $file_type";
+    print "\nFile Type: $apptype";
 
     print "\n" . "-" x 62 . "\n";
     if ($sort != $FIL_SORT_STR) {
